#
# spec file for package yelp
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Starting with openSUSE 11.3 we use tracker instead of beagle
%define no_beagle 0%{suse_version} >= 1130

%if %suse_version >= 1140
%define xulrunner_version 20
%endif
%if %suse_version == 1130
%define xulrunner_version 192
%endif
%if %suse_version == 1120
%define xulrunner_version 191
%endif
%if 0%{?xulrunner_version} == 0
%define xulrunner_version NOTSUPPORTED
%endif

Name:           yelp
BuildRequires:  dbus-1-glib-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gconf2-devel
BuildRequires:  gnome-common
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  gtk2-devel
BuildRequires:  intltool
%if !%no_beagle
BuildRequires:  libbeagle-devel
%endif
BuildRequires:  libxslt-devel
BuildRequires:  mozilla-xulrunner%{xulrunner_version}-devel
BuildRequires:  rarian-devel
BuildRequires:  startup-notification-devel
BuildRequires:  susehelp
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
License:        GPLv2+ ; LGPLv2.1+
Group:          System/GUI/GNOME
Version:        2.30.2
Release:        9.14.1
Summary:        Help Browser for the GNOME Desktop
Source:         ftp://ftp.gnome.org/pub/GNOME/sources/yelp/2.12/%{name}-%{version}.tar.bz2
Url:            http://www.gnome.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# PATCH-FIX-UPSTREAM yelp-fix-URI-handler.patch bgo#631678 badshah400@gmail.com -- Register scheme-related mimetypes with yelp
Patch0:         yelp-fix-URI-handler.patch
# PATCH-FIX-OPENSUSE yelp-no-xulrunner20.patch vuntz@opensuse.org -- Do not try to use xulrunner 2.0, as it's not working.
Patch1:         yelp-no-xulrunner20.patch
# PATCH-FIX-OPENSUSE yelp-xulrunner20.patch vuntz@opensuse.org -- Port to xulrunner 2.0. Note that upstream moved to webkit, so there's no point in sending the patch upstream.
Patch2:         yelp-xulrunner20.patch
# PATCH-FEATURE-OPENSUSE yelp-2.13.5-use-susehelp.patch -- make gnome-help a symlink to susehelp for better cross-desktop compatibility
Patch6:         yelp-2.13.5-use-susehelp.patch
# PATCH-FEATURE-OPENSUSE yelp-handle-help-uri.patch vuntz@novell.com -- handle help: URI
Patch9:         yelp-handle-help-uri.patch
# PATCH-FIX-UPSTREAM yelp-missing-slash.patch dimstar@opensuse.org - Use g_build_filename to avoid missing slash problem, taken from git.
Patch10:        yelp-missing-slash.patch
# PATCH-FIX-UPSTREAM yelp-fix-crash-on-print.patch bgo#642808 vuntz@opensuse.org -- Fix crash when printing a whole document: we were freeing memory we shouldn't.
Patch11:        yelp-fix-crash-on-print.patch
# PATCH-FIX-UPSTREAM yelp-fix-html-print.patch bgo#642811 vuntz@opensuse.org -- Fix crash when printing a pure HTML document
Patch12:        yelp-fix-html-print.patch
# PATCH-FIX-UPSTREAM yelp-no-freeze-on-window-move.patch bgo#642813 vuntz@opensuse.org -- Fix freeze when yelp window is moved. Similar to ce9025fffd63568305313cd7fddbd17fd8e058f5 upstream for the new yelp
Patch13:        yelp-no-freeze-on-window-move.patch
Provides:       suse_help_viewer
# We need the stylesheets from gnome-doc-utils
Requires:       gnome-doc-utils
Requires:       mozilla-xulrunner%{xulrunner_version}
Requires:       susehelp
Recommends:     %{name}-lang
%gconf_schemas_prereq

%description
Yelp is the default help browser for the GNOME desktop. Yelp provides a
simple graphical interface for viewing DocBook, HTML, man, and info
formatted documentation.

%lang_package
%prep
%setup -q
translation-update-upstream
%patch0 -p1
%if %xulrunner_version != 20
%patch1 -p1
%else
%patch2 -p1
%endif
%patch6 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1

%build
%if %xulrunner_version == 20
autoreconf -fi
%endif
%configure
make %{?jobs:-j%jobs}

%install
%makeinstall
%if 0%{?suse_version} <= 1110
%{__rm} %{buildroot}%{_datadir}/locale/la/LC_MESSAGES/*
%endif
%if 0%{?suse_version} <= 1120
%{__rm} %{buildroot}%{_datadir}/locale/en@shaw/LC_MESSAGES/*
%endif
%suse_update_desktop_file %name
%find_lang %{name} %{?no_lang_C}
%find_gconf_schemas
cat %{name}.schemas_list >%{name}.lst
%fdupes $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%pre -f %{name}.schemas_pre

%posttrans -f %{name}.schemas_posttrans

%preun -f %{name}.schemas_preun

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files -f %{name}.lst
%defattr (-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README
%{_bindir}/*
%{_datadir}/applications/yelp.desktop
%{_datadir}/icons/hicolor/192x192/apps/yelp-icon-big.png
%{_datadir}/yelp

%files lang -f %{name}.lang

%changelog
* Mon May  9 2011 vuntz@opensuse.org
- Update yelp-xulrunner20.patch to accepter 2.0.* versions of
  xulrunner. This makes yelp work with the latest update of Firefox
  in 11.4 (bnc#692429).
* Sun Feb 20 2011 vuntz@opensuse.org
- Port to xulrunner2 on 11.4 and later:
  - Add yelp-xulrunner20.patch to port the build system and code.
  - Do not apply yelp-no-xulrunner20.patch when we build against
    xulrunner2.
  - Call autoreconf when we build against xulrunner2.
  - Use mozilla-xulrunner20-devel BuildRequires on 11.4 and later.
- Add yelp-no-freeze-on-window-move.patch to fix freezes when the
  yelp window is moved: this is happening because we synchronously
  save a file, with a fsync() call. And that hits us really hard
  when a window is moved because we do that several times.
- Add yelp-fix-crash-on-print.patch: this fixes a crash when
  printing a complete document.
- Add yelp-fix-html-print.patch: this fixes a crash and infinite
  loop when printing a pure HTML document.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Jan 25 2011 dimstar@opensuse.org
- Add yelp-missing-slash.patch: fix issues with missing slashes
  when opening help files.
* Fri Dec 10 2010 vuntz@opensuse.org
- Add yelp-no-xulrunner20.patch: this tells yelp to not try to use
  xulrunner 2.0, which doesn't work with yelp right now.
- Add an explicit Requires for
  mozilla-xulrunner%%{xulrunner_version} to make sure the right
  version of xulrunner is installed.
- This fixes bnc#656953.
* Wed Dec  8 2010 badshah400@gmail.com
- Add yelp-fix-URI-handler.patch to register relevant scheme MIME
  types with yelp. This is needed because of a change in how gio
  works.
- Call %%desktop_database_post/%%desktop_database_postun in
  %%post/%%postun.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.30.2:
  + bgo#615457: Fixed "Open Link in New Window"
  + bgo#615141: Fixed TOC title internationalization
  + Updated translations.
* Mon Jun 14 2010 vuntz@opensuse.org
- Do not change yelp.desktop: it has OnlyShowIn=GNOME; and there's
  no reason in GNOME to change it.
* Sun May 23 2010 vuntz@opensuse.org
- Drop libbeagle-devel BuildRequires on 11.3 and later as part of
  our move away from beagle. This is fate#307899.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Support relocatable .gnome2 directory
  + Don't break on info pages with "/" in title
  + Updated translations:
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Mon Feb 22 2010 dimstar@opensuse.org
- Update to version 2.29.5:
  + Clean up GLib and GTK+ includes
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.4:
  + Updated translations.
* Tue Jan 26 2010 vuntz@opensuse.org
- Update to version 2.29.3:
  + Fixed issues with xulrunner 1.9.2.
- Build with mozilla-xulrunner192.
* Fri Jan 15 2010 vuntz@opensuse.org
- Update to version 2.29.2:
  + Adapted to changes in gnome-doc-utils XSLT
* Wed Jan  6 2010 vuntz@opensuse.org
- Update to version 2.29.1:
  + Fixed admonition graphics
  + Upped gnome-doc-utils version for fancy new Mallard features
  + Use accessor functions instead direct access
  + Updated translations.
* Tue Dec  1 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Use g_timeout_add_seconds to reduce wakeups, bgo#581260
  + Removed debug output, bgo#585829
  + Updated translations.
- Drop yelp-remove-debug.patch: fixed upstream.
- Update the way we remove the la locale for old versions of
  openSUSE.
* Fri Nov 13 2009 dimstar@opensuse.org
- Refresh patches to apply with fuzz=0.
* Mon Sep 21 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Drop yelp-nspr-includes.patch: it's not needed anymore.
- Remove autoreconf call.
* Tue Sep  8 2009 dimstar@opensuse.org
- Update to version 2.27.5:
  + Fixed broken history navigation for Mallard documents
  + Make sure link title roles are preserved in cache
  + Fixed jumping to anchors in Mallard documents
  + updated translations.
- nds@NFE has been renamed to nds upstream. No longer chaning it in
  the prep section.
* Fri Aug 28 2009 vuntz@novell.com
- Remove libglade2-devel and libgnomeui-devel BuildRequires.
- Add dbus-1-glib-devel, gconf2-devel and gtk2-devel BuildRequires.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 2.27.4:
  + Make ghelp URIs work for Mallard documents
  + Replace libgnome by using EggSMClient
  + Updated translations.
* Tue Aug  4 2009 vuntz@novell.com
- Add Requires on gnome-doc-utils, since we need the stylesheets to
  correctly work. Fix bnc#520101.
* Tue Jul 28 2009 dominique-obs@leuenberger.net
- Update to version 2.27.3:
  + Various code updates
  + Updated translations.
* Tue Jul 21 2009 wr@rosenauer.org
- Build against mozilla-xulrunner191
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.27.2:
  + Require Mallard-enabled gnome-doc-utils
  + Fixed various memory management bugs
  + Updated translations.
* Mon Jun 15 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Added experimental support for Mallard
  + Fixed various color theme issues
- Drop yelp-gio-port-issues.patch: fixed upstream.
- Add yelp-remove-debug.patch to remove debug output.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Don't assume order of certain man macros, bgo#568066
  + Fixed locking issue, bgo#568058
  + Updated translations.
- Remove AutoReqProv: it's default now.
- Drop help-title.png: it's not used.
- Remove unneeded BuildRequires: perl-XML-Parser
- Remove unneeded Requires: gnome-utils, gnome-doc-utils
- Remove Requires that are automatically added: libbeagle,
  mozilla-xulrunner
- Remove PreReq: filesystem (unnecessary to specify it), gconf2
  (included in gconf_schemas_prereq)
* Tue Mar 10 2009 vuntz@novell.com
- Fix build on openSUSE 11.1 and earlier.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.1:
  + RTL fixes, bgo#573159
  + Fixed libxul[-embedding] detection
  + Removed deprecated GTK symbols, bgo#571868
  + Fixed crasher, bgo#552947
  + Fixed loading of local HTML files, bgo#562137
  + Updated translations.
- Update yelp-gio-port-issues.patch: part of it was fixed upstream.
- Rebase yelp-nspr-includes.patch.
- Remove -fno-strict-aliasing from CFLAGS.
- Use makeinstall.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sat Nov 29 2008 vuntz@novell.com
- Update yelp-gio-port-issues.patch to fix help not working in
  GNOME applications. Fix bnc#449516.
* Fri Oct 31 2008 vuntz@novell.com
- Add yelp-gio-port-issues.patch to fix HTML help (the openSUSE
  help is all HTML...). Fix bnc#439883.
- Kill yelp-onlyshowin.patch: fixed upstream.
- Clean spec.
* Mon Sep 22 2008 maw@suse.de
- Update to version 2.24.0:
  + Improve a11y under gecko 1.9 (bgo#545162, and drop
    yelp-html.patch as a result)
  + Fix potential race-condition (bgo#551757)
  + fd.o categorisation improvements (bgo#552128)
  + Updated translations
- Respin yelp-onlyshowin.patch.
* Fri Sep 12 2008 maw@suse.de
- Add yelp-html.patch (bgo#545162, and necessary for orca support).
* Tue Sep  2 2008 mboman@novell.com
- Update to version 2.23.91:
  * Fix loading of text files - bgo#549986
  * Fix glibc info manual chrash - bgo#520266
  * Updated translations:
* Tue Aug 26 2008 mboman@novell.com
- Update to version 2.23.2:
  + Fix string vulnerability [bgo#546364]
  + Use "help-browser" icon instead of deprecated "gnome-help"
* Mon Jun 23 2008 maw@suse.de
- Update to version 2.23.1:
  + Support for Gecko 1.9, provided by mozilla-xulrunner190;
    accordingly, yelp-xulrunner190.patch has been dropped
  + Use gio in lieu of gnome-vfs
  + Fix searching on multibyte characters
  + Support for newer versions of Beagle
  + Make "print whole document" work again
  + Only show the help browser in GNOME menus, because other
    desktops should ship their own help browser
  + Updated translations
- Add yelp-nspr-includes.patch.
* Wed May  7 2008 vuntz@suse.de
- Drop yelp-desktop.patch: the generic name is set via
  %%suse_update_desktop_file, so no need to patch.
* Mon Apr 28 2008 maw@suse.de
- Add yelp-xulrunner190.patch, to enable building against
  mozilla-xulrunner190.
* Wed Apr 23 2008 vuntz@suse.de
- Drop two patches that needed rebasing: yelp-suse-20060319.patch
  and yelp-2.14.0-process-suse-manuals.patch. The first one
  shouldn't be needed anymore because of yelp-handle-help-uri.patch
  The second one will be replaced by a fix in the opensuse manual
  packages.
* Wed Apr 23 2008 vuntz@suse.de
- Drop yelp-2.18.1-empty-doc-crash.patch: doesn't apply anymore and
  seems to be fixed upstream now (crash not reproducable).
- Tag yelp-2.13.5-use-susehelp.patch.
- Add yelp-handle-help-uri.patch to handle help: URIs. Based on
  some code from yelp-suse-20060319.patch.
* Fri Apr 11 2008 vuntz@suse.de
- Update to version 2.22.1:
  + Don't launch external programs under GDM (bgo#525447)
  - Distributors please note this is a security issue
  + Updated translations
* Mon Mar 17 2008 vuntz@suse.de
- Remove yelp-libxslt.patch, it was kept for suse version < 9.2.
- Tag yelp-onlyshowin.patch.
* Thu Mar 13 2008 vuntz@suse.de
- Update to version 2.22.0:
  + Fix bgo#476498
  + Remove some unwanted debug spew
  + Updated translations
* Wed Mar  5 2008 maw@suse.de
- Update to version 2.21.90:
  + Many bug fixes
  + Updated translations
- Drop yelp-autobuild-warning.patch; don't apply several others,
  which need to be evaluated and then rebased or dropped.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Fri Sep 14 2007 hpj@suse.de
- Update yelp-suse-20060319.patch to find docs in the help-bundle/
  dir in addition to help/.
* Fri Sep 14 2007 jpr@suse.de
- Revert to 2.18.1
- Add yelp-2.18.1-empty-doc-crash.patch, which prevents a crash
  when trying to load an empty doc.
* Sat Sep  1 2007 hpj@suse.de
- Add yelp-2.19.90-freed-memory-crash.patch (BGO #469436).
- Add yelp-2.19.90-freed-memory-crash-2.patch (BGO #469438).
- Add yelp-2.19.90-no-mime-type-crash.patch (BGO #472128).
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.90:
  + Build fixes
  + Use x-yelp-index instead of index, unbreaking some docbook
    files
  + Write html on demand instead of when idle, fixing info page
    usage
  + Add a "phrase not found" message to the find bar
  + Fix "info <page>" in the serach bar
  + Register EXSLT extensions
  + Other bugs (bugzilla.gnome.org) fixed: #447107, #431078,
    [#430365], #381431, #364768, #370167, #358825, #464295, #457082,
    [#462440], #462813, #450168, #463281, #458693, and #462056
  + Updated translations.
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage.
* Sat Aug  4 2007 maw@suse.de
- Buildrequire rarian-devel, not rarian
- Use %%fdupes
- Add abuild.patch.
* Fri Aug  3 2007 mauro@suse.de
- Update to version 2.19.2
- Test programs are disabled for now.
- Merge of the yelp rework branch.
- New themes are working now.
- Make loading of files directly work again.
- Search across is using Rarian now.
- mp-search-parser.patch was added to fix search-parser.c
* Thu May 10 2007 pgajdos@suse.cz
- removed gnome-icon-theme from BuildRequires [#247450]
* Thu Apr 12 2007 maw@suse.de
- Update to version 2.18.1 which has updated translations for
  the eu, gl, it, ku, mk, sq, sv, and tr locales.
* Mon Apr  9 2007 maw@suse.de
- Update to version 2.18.0
- Mozilla API changes/fixes.
* Sat Mar 10 2007 maw@suse.de
- Update to version 2.16.2.
  * Don't crash when manpath is unavailable
  * Remove markup from translated messages (#360450)
  * Fix info links (#364850)
  * Fix various search crashes (#363949, #364768)
  * Don't crash when session-saving (#364790)
  * More info page crash fixes (#367410, 376861, 371680)
  * Fix print ranges (#370618)
* Fri Dec 22 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Dec 15 2006 hpj@suse.de
- Include GNOME Computer Based Training docs in search path. FATE
  [#301047].
* Thu Nov 30 2006 sbrabec@suse.cz
- Fixed xulrunner dependencies for older products.
* Wed Nov 22 2006 hpj@suse.de
- Update yelp-suse-20060319.patch to include correct search path
  for KDE documents.
* Tue Nov  7 2006 sbrabec@suse.cz
- Use exact xulrunner version 181 (#216100).
* Wed Nov  1 2006 hpj@suse.de
- Updated yelp-suse-20060319.patch to fix Novell bug #210429,
  Novell bug #215411 and the fact that you could not go backwards
  to the TOC.
* Wed Oct 18 2006 jhargadon@suse.de
- modified yelp-2.14.0-process-suse-manuals.patch to include
  opensuse-manual and opensuse-gnomeuser docs.
* Sat Oct 14 2006 danw@suse.de
- Remove dead patch
* Fri Oct 13 2006 aj@suse.de
- Add gnome-doc-utils-devel to BuildRequires.
- Cleanup BuildRequires.
- Use RPM_OPT_FLAGS.
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.16.1
- Set initial caret state properly in prefs
- Fix build with gecko trunk
- Prefer xulrunner over mozilla
- translation updates
* Fri Sep 15 2006 jhargadon@suse.de
- update to version 2.16.0
- Fix a crash when the category is missing for a document
- Fix a crash with bzip streams
- Move online url to perminant address at gnome.org
- Suppress critical warnings when they aren't critical
- Other info file fixes
- Fix crash when apropos goes nuts, fixes bug #347467
- Fix crash on CVS info file
- translation updates
- added patch to eliminate autobuild warnings in src/yelp-main.c
* Fri Aug 25 2006 jhargadon@suse.de
- update to version 2.15.91
- Fix search results to be accessible
- Change "Sound & Vision" to "Sound & Video" in TOC
- Fix dbus threading in some cases
- Remove online search translation
- Updated Translations
- Fix stale socket problem when Beagle is used
- Many TOC structure changes
- On demands page loads for TOC
- Expand/collapse on double-click.
- Fix to properly escape ampersand characters
- fix big memory leak (use xmlFreeDoc, not xmlFree)
* Fri Jul  7 2006 lrupp@suse.de
- Fixed mozilla/xulrunner/xulrunner180 dependencies
* Tue May 23 2006 hpj@suse.de
- Updated patch to make it show more SuSE-specific manuals if
  present. Fixes Novell bug #173181.
* Thu May 11 2006 hpj@suse.de
- Updated patch to address the specific case of help:// URIs with
  full path and a section. Also try to look for local DTDs before
  loading them from potential network URIs, which makes it a lot
  faster. Fixes Novell bug #161056.
* Wed Apr 19 2006 hpj@suse.de
- Added a patch to pick up the SUSE manuals if present.
* Wed Apr  5 2006 hpj@suse.de
- Updated patch to be better at finding HTML index files.
* Sun Mar 19 2006 hpj@suse.de
- Updated patch to resolve even more cases of broken help URIs,
  missing DTDs and other external entities. Also fall back to
  English-language external entities (like pictures) if they can't
  be found in the preferred language, and create bookmarks with
  either '?' or '#' section demarcation correctly. Fixes at least
  Novell bugs #158769 and #155271.
* Sat Mar 18 2006 hpj@suse.de
- Updated patch to be even more tolerant of broken help URIs.
  Fixes at least Novell bugs #157790, #157781 and $157775, probably
  others not files yet.
* Sat Mar 18 2006 joeshaw@suse.de
- Add a patch which fixes some misuse of the libbeagle API.
  Fixes bnc #157801, sent upstream as bgo #334938.
* Mon Mar 13 2006 jpr@suse.de
- Update to 2.14.0 which includes some of our upstreamed patches
- Changes
  * Sort search results to provide some sanity                 (Don Scorgie)
  * Fix space problem with manpage search on FreeBSD           (Don Scorgie)
  * If beagle daemon is not running fall back to basic search  (Joe Shaw)
  * Removed redundant search text entry                        (Joe Shaw)
  * Fix some memory leaks                                      (Brent Smith)
  * Re-applied a11y patch                                      (Brent Smith)
  * set MOZ_DISABLE_PANGO in environ to fix broken characters  (Brent Smith)
  * Escape characters when searching                           (Don Scorgie)
  * Fix resizing issues by focus print preview on html widget  (Don Scorgie)
  * Updated translations
* Fri Mar 10 2006 dobey@suse.de
- Modify help-title.png to be narrower
  Fixes https://bugzilla.novell.com/show_bug.cgi?id=156481
* Mon Mar  6 2006 dobey@suse.de
- Update help-title.png to follow new color/branding
* Sat Mar  4 2006 hpj@suse.de
- Fix yelp-suse patch to show fragments specified by ? at the end
  of URIs.
* Sat Mar  4 2006 hpj@suse.de
- Fix yelp-suse patch to show help:// docs in languages other than
  C if present and desired.
* Sat Mar  4 2006 hpj@suse.de
- Use susehelp to show GNOME docs instead of invoking yelp
  directly.
* Sat Feb 18 2006 gekker@suse.de
- fixup .desktop file for ui team
* Sat Feb 18 2006 joeshaw@suse.de
- Update SUSE yelp patch to disable search UI when Beagle is not
  available (as on SLES).
- Remove redundant search entry on table-of-contents and search
  results pages
* Thu Feb 16 2006 joeshaw@suse.de
- Update package to 2.13.5 (fixes bnc 151224 and other 64-bit
  issues)
- Regenerate SUSE yelp patch against it.
  Upstream changelog:
  Changes in 2.13.5:
  * Reverted a11y patch due to issues finding registry      (Brent Smith)
  * 64-bit cleanups related to gsize                        (Robert Harris)
  * Small speedups in TOC processing                        (Brent Smith)
  * Fixed crash with malformed documents                    (Brent Smith)
  * Make relative paths work with second instance of yelp   (Brent Smith)
  * Remove references functions that no longer exist        (Brent Smith)
  * Updated translatations:
  ca      (Josep Puigdemont i Casamajó)
  da      (Lasse Bang Mikkelsen)
  el      (Kostas Papadimas)
  en_CA   (Adam Weinberger)
  es      (Francisco Javier F. Serrador)
  et      (Priit Laes)
  fi      (Ilkka Tuohela)
  gl      (Ignacio Casal Quinteiro)
  gu      (Ankit Patel)
  nb      (Kjartan Maraas)
  nl      (Tino Meinen)
  no      (Kjartan Maraas)
  sq      (Laurent Dhima)
  sr      (Slobodan D. Sredojevic)
  th      (Theppitak Karoonboonyanan)
  vi      (Clytie Siddall)
  zh_CN   (Funda Wang)
* Wed Feb  1 2006 joeshaw@suse.de
- Update package to 2.13.4 (fixes bnc 146353)
- Regenerate SUSE yelp patch against it.
  Changes in 2.13.4:
  * Bury man and info under 'Command Line Help'             (Shaun
  McCance)
  * Workaround for a11y issues.  Should fix bug #157941     (Don Scorgie)
  * Added support for mapping severl man sections, #328172  (Brent Smith)
  * Fixed some memory leaks                                 (Don Scorgie)
  * More robust handling for basic search, #328464          (Don Scorgie)
  * Fixed in TOC handling, #328953                          (Brent Smith)
  * Use the new document font setting by default            (Brent Smith)
  * Fixed some C99 initializations, #328261                 (Jens
  Granseuer)
  * Fixed a critical warning                                (Brent Smith)
  * Use a newer Beagle for Beagle search                    (Don Scorgie)
  * More robus GConf error handling, #327826                (Brent Smith)
  * Added GTK to the desktop file categories                (Brent Smith)
  * Fixed loading of non-compressed man and info            (Don Scorgie)
  * Fixed crashes on malformed info:dir files               (Don Scorgie)
  * Fixed compilation issues on Solaris                     (Glynn Foster)
  * Updated translations:
  bg      (Vladimir Petkov)
  ca      (Josep Puigdemont i Casamajó)
  da      (Lasse Bang Mikkelsen)
  da      (Lasse Bang Mikkelsen)
  en_CA   (Adam Weinberger)
  es      (Francisco Javier F. Serrador)
  fi      (Ilkka Tuohela)
  gl      (Ignacio Casal Quinteiro)
  gu      (Ankit Patel)
  hu      (Gabor Kelemen)
  lt       Beru ­ka)
  nb      (Kjartan Maraas)
  nl      (Tino Meinen)
  no      (Kjartan Maraas)
  pt_BR   (Evandro Fernandes Giovanini)
  ru      (razi)
  th      (Theppitak Karoonboonyanan)
  vi      (Clytie Siddall)
  zh_CN   (Funda Wang)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 joeshaw@suse.de
- Update package to 2.13.3; require libbeagle 0.2.0
* Fri Jan 13 2006 joeshaw@suse.de
- Update yelp-suse.patch to fix opening of KDE docs from the
  table of contents.
* Tue Jan 10 2006 joeshaw@suse.de
- Update yelp-suse.patch to fix a strict aliasing issue
* Tue Jan 10 2006 joeshaw@suse.de
- Update to version 2.13.2
- Regenerate and rename yelp-updates.patch to yelp-suse.patch,
  since most of the code is suse-specific.
* Thu Dec 22 2005 joeshaw@suse.de
- Update beagle patch, require libbeagle 0.1.4
* Thu Dec  1 2005 gekker@suse.de
- Update to version 2.12.2
- Remove upstreamed patch
* Wed Nov 16 2005 sbrabec@suse.cz
- Fixed mozilla/xulrunner dependencies.
* Thu Oct 20 2005 clahey@suse.de
- New yelp-updates.patch.  Fixes some search bugs.
* Thu Oct 13 2005 gekker@suse.de
- Update to version 2.12.1
* Thu Oct 13 2005 ro@suse.de
- build with xulrunner
* Thu Oct  6 2005 gekker@suse.de
- Fixup .desktop file
* Wed Oct  5 2005 clahey@suse.de
- Provide suse_help_viewer.
* Fri Sep 16 2005 clahey@suse.de
- Made yelp actually find docbook files. (dumb typo.)
* Tue Sep  6 2005 sbrabec@suse.cz
- Removed outdated ORBit work-around.
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 2.12.0.
* Wed Aug 24 2005 gekker@suse.de
- Update to version 2.11.92
- Rediff yelp-updates.patch so that it applies agains the new version
* Wed Aug 24 2005 clahey@suse.de
- Updated yelp-updates.patch.  Makes search just show the top ten
  results.  Fixed bug where only one search is actually done.
* Tue Aug 23 2005 clahey@suse.de
- Updated yelp-updates.patch.  Fixes print this document, search
  appearance, and help: parsing.
* Fri Aug 19 2005 clahey@suse.de
- Updated yelp-updates.patch
* Fri Aug 19 2005 ro@suse.de
- move code from previous change from post to install section
* Tue Aug 16 2005 sbrabec@suse.cz
- Fixed requirement to not require symbols provided only by
  mozilla-nss and mozilla-nspr packages (#98002).
* Fri Jul 29 2005 clahey@suse.de
- Updated yelp-updates.patch.
* Sat Jul 23 2005 gekker@suse.de
- Update to version 2.11.1
- Remove upstreamed patch
* Tue Jul 19 2005 jpr@suse.de
- Fix required beagle version
* Wed Jul  6 2005 clahey@suse.de
- Updated to cvs head and added a bunch of code that isn't in cvs yet.
* Wed Jun 22 2005 gekker@suse.de
- Update to version 2.10.0
- Fix warnings
* Wed Feb 16 2005 ke@suse.de
- Must require gnome-doc-utils; [# 50808].
* Mon Feb  7 2005 gekker@suse.de
- Update to version 2.9.3
* Mon Jan 24 2005 clahey@suse.de
- Updated to version 2.9.2.
* Wed Oct 27 2004 mmj@suse.de
- Correct locale rename
- Don't remove buildroot before install
* Tue Oct 26 2004 mmj@suse.de
- Locale rename no to nb
* Wed Sep  8 2004 clahey@suse.de
- Add OnlyShowIn=GNOME;.
* Wed Jun  9 2004 clahey@suse.de
- Patch out libxslt 1.1.4 requirements.
* Mon May 10 2004 sbrabec@suse.cz
- Updated to version 2.6.1 (GNOME 2.6).
* Fri Feb 20 2004 sbrabec@suse.cz
- Fixed names of GNOME2 packages.
* Mon Feb  9 2004 hhetter@suse.de
- updated to version 2.4.2 [GNOME2.4.2]
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.4.1.
* Tue Sep  9 2003 hhetter@suse.de
- updated to 2.4.0 (translation release)
* Fri Aug 15 2003 adrian@suse.de
- add Documentation Category
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 26 2003 sbrabec@suse.cz
- Updated to version 2.2.3.
* Thu Jun 26 2003 sbrabec@suse.cz
- Updated to version 2.2.2.
- Updated neededforbuild.
- Use %%find_lang.
* Tue Jun 17 2003 ro@suse.de
- added directories to filelist
* Fri Feb  7 2003 hhetter@suse.de
- updated to version 2.2.0 [GNOME 2.2.0]
* Thu Jan 16 2003 sbrabec@suse.cz
- Added libjpeg to neededforbuild.
* Tue Nov 19 2002 hhetter@suse.de
- updated to version 1.0.7
  * improved translation and updates
- removed wrapper script
* Tue Nov 12 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Wed Oct 23 2002 hhetter@suse.de
- updated to stable version 1.0.6
- FHS fix
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
* Thu Sep 19 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Wed Aug 14 2002 hhetter@suse.de
- updated to version 1.0.3
  * Fixed a bug that caused Yelp to segfault on
  startup if you used MANPATH instead of
  manpath
  * Stylesheet improvments
  * Updated translations (pt)
* Wed Aug  7 2002 hhetter@suse.de
- updated to version 1.0.2
  * libexec movement
  * translation updates
* Mon Jul 29 2002 hhetter@suse.de
- added wrapper for yelp to ensure scrollkeeper updates
* Wed Jun 19 2002 hhetter@suse.de
- updated to version 1.0.1
  * translation updates
* Tue Jun 11 2002 hhetter@suse.de
- updated to version 1.0
* Wed Jun  5 2002 ro@suse.de
- use libdir for configure
* Wed Jun  5 2002 hhetter@suse.de
- initial SuSE Release
